
package 
AWS::S3::Response;

use VSO;

1;# return true:

